@@ -48,6 +48,7 @@ class MessageRowActions(Gtk.EventBox):
             self,
             halign=Gtk.Align.END,
             valign=Gtk.Align.START,
+            margin_start=40,
             margin_end=40,
             no_show_all=True,
         )
@@ -117,8 +118,13 @@ class MessageRowActions(Gtk.EventBox):
         if y_coord < self_height:
             y_coord = self_height
 
-        # Subtract 12 to let MessageRowActions 'flow' above the row
-        adjusted_y_coord = y_coord - 12
+        # Subtract some space to let MessageRowActions 'flow' above the row,
+        # but make sure to make offset smaller than row height.
+        offset = 12
+        if self._message_row.is_merged:
+            offset = min(28, self_height - 6)
+
+        adjusted_y_coord = y_coord - offset
         if adjusted_y_coord < 0:
             adjusted_y_coord = 0
 
@@ -126,13 +132,22 @@ class MessageRowActions(Gtk.EventBox):
         self.set_no_show_all(False)
         self.show_all()
 
+        message_row_width = self._message_row.get_allocated_width()
         reactions_visible = self._get_reactions_visible()
+
         for button in self._reaction_buttons:
+            if (isinstance(button, QuickReactionButton) and reactions_visible and
+                    message_row_width < 600):
+                # Don't show QuickReactionButtons on narrow screens
+                button.set_visible(False)
+                continue
+
             button.set_visible(reactions_visible)
 
         self._reply_button.set_visible(self._get_reply_visible())
 
     def switch_contact(self, contact: ChatContactT) -> None:
+        self._message_row = None
         self._contact = contact
 
     def _get_reply_visible(self) -> bool:
@@ -202,7 +217,6 @@ class MessageRowActions(Gtk.EventBox):
             event.type == Gdk.EventType.LEAVE_NOTIFY
             and event.detail != Gdk.NotifyType.INFERIOR
         ):
-
             self._has_cursor = False
             self._timeout_id = None
 
@@ -211,8 +225,8 @@ class MessageRowActions(Gtk.EventBox):
                 # but we don't want to hide MessageRowActions
                 return True
 
-            assert self._message_row is not None
-            self._message_row.get_style_context().remove_class('conversation-row-hover')
+            if self._message_row is not None:
+                self._message_row.get_style_context().remove_class('conversation-row-hover')
 
             self.hide()
 
