@@ -41,9 +41,6 @@ from gajim.gtk.util import get_app_window
 from gajim.gtk.util import open_window
 from gajim.gtk.video_preview import VideoPreview
 
-# if app.is_installed('GSPELL'):
-#     from gi.repository import Gspell  # pylint: disable=ungrouped-imports
-
 log = logging.getLogger('gajim.gtk.preferences')
 
 
@@ -920,7 +917,9 @@ class Miscellaneous(PreferenceBox):
 
     @staticmethod
     def _get_proxies() -> dict[str, str]:
-        return {proxy: proxy for proxy in app.settings.get_proxies()}
+        proxies = {proxy: proxy for proxy in app.settings.get_proxies()}
+        proxies['no-proxy'] = _('No Proxy')
+        return proxies
 
     @staticmethod
     def _on_proxy_edit(*args: Any) -> None:
