@@ -4,8 +4,6 @@
 
 from __future__ import annotations
 
-from typing import cast
-
 from gi.repository import Gtk
 from gi.repository import Pango
 from nbxmpp.modules.security_labels import SecurityLabel
@@ -20,46 +18,39 @@ from gajim.common.i18n import _
 from gajim.common.types import ChatContactT
 
 
-class SecurityLabelSelector(Gtk.ComboBox):
+class SecurityLabelSelector(Gtk.ComboBoxText):
     def __init__(self) -> None:
-        Gtk.ComboBox.__init__(self, no_show_all=True)
-        self._account: str | None = None
+        Gtk.ComboBoxText.__init__(self, no_show_all=True)
+
         self._client: Client | None = None
         self._contact: ChatContactT | None = None
 
+        text_renderer = self.get_cells()[0]
+        text_renderer.set_property('ellipsize', Pango.EllipsizeMode.END)
+        text_renderer.set_property('max-width-chars', 20)
+
         self.set_valign(Gtk.Align.CENTER)
         self.set_tooltip_text(_('Select a security label for your message…'))
 
-        label_store = Gtk.ListStore(str)
-        self.set_model(label_store)
-        label_cell_renderer = Gtk.CellRendererText()
-        label_cell_renderer.set_property('ellipsize', Pango.EllipsizeMode.END)
-        label_cell_renderer.set_property('max-width-chars', 14)
-        self.pack_start(label_cell_renderer, True)
-        self.add_attribute(label_cell_renderer, 'text', 0)
-
         app.ged.register_event_handler(
             'sec-catalog-received', ged.GUI1, self._sec_labels_received)
 
-        self.connect('changed', self._on_changed)
         self.connect('destroy', self._on_destroy)
 
     def switch_contact(self, contact: ChatContactT) -> None:
-        app.settings.disconnect_signals(self)
-        if self._client is not None:
-            self._client.disconnect_all_from_obj(self)
+        self.clear()
 
-        self._account = contact.account
         self._client = app.get_client(contact.account)
         self._contact = contact
 
         app.settings.connect_signal(
             'enable_security_labels',
             self._on_setting_changed,
-            account=self._account)
+            account=self._contact.account)
         self._client.connect_signal(
             'state-changed', self._on_client_state_changed)
-        self._update()
+
+        self._update_combo_box()
 
     def _on_destroy(self, _widget: SecurityLabelSelector) -> None:
         app.ged.remove_event_handler('sec-catalog-received',
@@ -67,22 +58,14 @@ class SecurityLabelSelector(Gtk.ComboBox):
                                      self._sec_labels_received)
         app.check_finalize(self)
 
-    def _on_changed(self, _combo: Gtk.ComboBox) -> None:
-        iter_ = self.get_active_iter()
-        if iter_ is None:
-            return
-
-        model = self.get_model()
-        label_text = model.get_value(iter_, 0)
-        self.set_tooltip_text(
-            _('Selected security label: %s') % f'\n{label_text}')
-
     def _on_client_state_changed(self,
                                  _client: Client,
                                  _signal_name: str,
-                                 _state: SimpleClientState
+                                 state: SimpleClientState
                                  ) -> None:
-        self._update()
+
+        if state == SimpleClientState.CONNECTED:
+            self._update_combo_box()
 
     def _on_setting_changed(self,
                             state: bool,
@@ -90,65 +73,79 @@ class SecurityLabelSelector(Gtk.ComboBox):
                             _account: str | None,
                             _jid: JID | None
                             ) -> None:
-        self.set_no_show_all(not state)
+
         if state:
-            self.show_all()
+            self._update_combo_box()
         else:
             self.hide()
-        self._update()
+            self.remove_all()
 
     def _sec_labels_received(self, event: SecCatalogReceived) -> None:
-        if self._account is None or self._account != event.account:
+        if self._contact is None or self._contact.account != event.account:
             return
 
-        if self._contact is None:
+        if event.jid != self._contact.jid:
             return
 
-        if event.jid != self._contact.jid.bare:
-            return
+        self._update_combo_box()
 
-        if not app.settings.get_account_setting(
-                self._account, 'enable_security_labels'):
-            return
-
-        model = cast(Gtk.ListStore, self.get_model())
-        model.clear()
-
-        selection = 0
-        label_list = event.catalog.get_label_names()
-        default = event.catalog.default
-        for index, label in enumerate(label_list):
-            model.append([label])
-            if label == default:
-                selection = index
-
-        self.set_active(selection)
-        self.set_no_show_all(False)
-        self.show_all()
-
-    def get_seclabel(self) -> SecurityLabel | None:
-        index = self.get_active()
-        if index == -1:
-            return None
+    def _update_combo_box(self) -> None:
 
         assert self._contact is not None
         assert self._client is not None
-        jid = self._contact.jid.bare
-        catalog = self._client.get_module('SecLabels').get_catalog(jid)
+
+        if not app.settings.get_account_setting(
+                self._contact.account, 'enable_security_labels'):
+            return
+
+        catalog = self._client.get_module('SecLabels').get_catalog(
+            self._contact.jid)
+
+        self.remove_all()
+
+        if catalog is not None:
+            for selector in catalog.get_label_names():
+                self.append(selector, selector)
+            self.set_active_id(catalog.default)
+
+        self.show()
+
+    def get_seclabel(self) -> SecurityLabel | None:
+        assert self._contact is not None
+        if not app.settings.get_account_setting(
+                self._contact.account, 'enable_security_labels'):
+            return
+
+        selector = self.get_active_text()
+        if selector is None:
+            return
+
+        assert self._client is not None
+        catalog = self._client.get_module('SecLabels').get_catalog(
+            self._contact.jid)
+        if catalog is None:
+            return None
+        return catalog.labels[selector]
+
+    def set_seclabel(self, label_hash: str) -> None:
+        assert self._contact is not None
+        assert self._client is not None
+
+        catalog = self._client.get_module('SecLabels').get_catalog(
+            self._contact.jid)
         if catalog is None:
             return None
 
-        labels, label_list = catalog.labels, catalog.get_label_names()
-        label_name = label_list[index]
-        return labels[label_name]
+        for selector, label in catalog.labels.items():
+            if label is None:
+                continue
+            if label.get_label_hash() == label_hash:
+                self.set_active_id(selector)
 
-    def _update(self) -> None:
-        assert self._account is not None
-        assert self._client is not None
-        assert self._contact is not None
+    def clear(self) -> None:
+        app.settings.disconnect_signals(self)
+        if self._client is not None:
+            self._client.disconnect_all_from_obj(self)
 
-        chat_active = app.window.is_chat_active(
-            self._account, self._contact.jid)
-        if chat_active:
-            self._client.get_module('SecLabels').get_catalog(
-                self._contact.jid.bare)
+        self._client = None
+        self._contact = None
